==> haskell-critbit-0.2.0.0-168-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 critbit
version:              0.2.0.0
visibility:           public
id:                   critbit-0.2.0.0-3DwT8WDfNJEChOHCDdcdmx
key:                  critbit-0.2.0.0-3DwT8WDfNJEChOHCDdcdmx
license:              BSD-3-Clause
copyright:            2013-2014 Bryan O'\''Sullivan and others
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/critbit
synopsis:             Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').

    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.

    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.

category:             Data
abi:                  0d6c88b456a66ffc2fb11edea3c31383
exposed:              True
exposed-modules:      Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules:
    Data.CritBit.Core Data.CritBit.Types.Internal Data.CritBit.Tree

import-dirs:          /usr/lib/ghc-9.0.1/site-local/critbit-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/critbit-0.2.0.0
hs-libraries:         HScritbit-0.2.0.0-3DwT8WDfNJEChOHCDdcdmx
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 deepseq-1.4.5.0
    text-1.2.4.1 vector-0.12.3.1-HMAplmdcuCN6dtD8e6QGwL

haddock-interfaces:   /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html:         /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-critbit-0.2.0.0-170-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-critbit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 critbit
version:              0.2.0.0
visibility:           public
id:                   critbit-0.2.0.0-598gr4MNzJG3NDwgY3WV0f
key:                  critbit-0.2.0.0-598gr4MNzJG3NDwgY3WV0f
license:              BSD-3-Clause
copyright:            2013-2014 Bryan O'\''Sullivan and others
maintainer:           Bryan O'\''Sullivan <bos@serpentine.com>
author:               Bryan O'\''Sullivan <bos@serpentine.com>
homepage:             https://github.com/bos/critbit
synopsis:             Crit-bit maps and sets
description:
    This package implements crit-bit trees, a key-value container type
    for storing keys that can be treated as bitstrings (e.g.
    '\''ByteString'\'' and '\''Text'\'').

    Compared to the data structures from the containers and
    unordered-containers packages, you will find that sometimes the
    functions implemented in this package are faster, sometimes
    slower.

    In many cases, a '\''CritBit'\'' tree provides performance close to that
    of a '\''HashMap'\'', while providing ordered storage and traversal
    like a '\''Map'\''.

category:             Data
abi:                  a594d946b6c619b8d4161375aeb1af86
exposed:              True
exposed-modules:      Data.CritBit.Map.Lazy Data.CritBit.Set
hidden-modules:
    Data.CritBit.Core Data.CritBit.Types.Internal Data.CritBit.Tree

import-dirs:          /usr/lib/ghc-9.0.1/site-local/critbit-0.2.0.0
library-dirs:         /usr/lib/ghc-9.0.1/site-local/critbit-0.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/critbit-0.2.0.0
hs-libraries:         HScritbit-0.2.0.0-598gr4MNzJG3NDwgY3WV0f
depends:
    array-0.5.4.0 base-4.15.0.0 bytestring-0.10.12.1 deepseq-1.4.5.0
    text-1.2.4.1 vector-0.12.3.1-BYdg1PRFj4WB38iHU29MVy

haddock-interfaces:   /usr/share/doc/haskell-critbit/html/critbit.haddock
haddock-html:         /usr/share/doc/haskell-critbit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
